DateTime

Struct DateTime 

pub struct DateTime<TZ> { /* private fields */ }
ISO-8601 representation with timezones.

Implementations

Source

impl<TZ> DateTime<TZ>
where TZ: TimeZone,

pub fn parse( bytes: &[u8], tokens: impl IntoIterator<Item = CalendarToken>, ) -> Result<Self>

Parses a sequence of bytes according to the specified tokens.

See CalendarToken for more information.

pub fn to_string<const N: usize>( &self, tokens: impl IntoIterator<Item = CalendarToken>, ) -> Result<ArrayStringU8<N>>

Creates a string representation based on the given tokens.

A string of 32 bytes is usually more than enough for most representations.

See CalendarToken for more information.

Source

impl DateTime<Utc>

pub const CE: Self

Instance that refers the common era (0001-01-01).

pub const EPOCH: Self

Instance that refers the UNIX epoch (1970-01-01).

pub const MAX: Self

Instance with the maximum allowed value of 32768-12-31 24:59:59.999_999_999

pub const MIN: Self

Instance with the minimum allowed value of -32768-01-01 00:00:00.000_000_000

pub fn from_timestamp_secs(second: i64) -> Result<Self>

Creates a new instance from a UNIX timestamp expressed in seconds.

pub fn from_timestamp_secs_and_ns( seconds: i64, nanoseconds: Nanosecond, ) -> Result<Self>

Creates a new instance from a UNIX timestamp expressed in seconds along side the number of nanoseconds.

Source

impl<TZ> DateTime<TZ>
where TZ: TimeZone,

pub fn from_iso8601(bytes: &[u8]) -> Result<Self>

Creates a new instance based on the string representation of the ISO-8601 specification.

pub const fn new(date: Date, time: Time, time_zone: TZ) -> Self

New instance from basic parameters

pub const fn add(self, duration: Duration) -> Result<Self, CalendarError>

Computes self + duration, returning an error if an overflow occurred.

pub const fn date(self) -> Date

See Date.

pub fn iso8601(self) -> ArrayStringU8<38>

ISO-8601 string representation

pub const fn sub(self, duration: Duration) -> Result<Self, CalendarError>

Computes self - duration, returning an error if an underflow occurred.

pub const fn time(self) -> Time

See Time.

pub const fn timestamp_secs_and_ns(self) -> (i64, Nanosecond)

UNIX timestamp in seconds as well as the number of nanoseconds.

It is worth noting that it is much cheaper to get the timestamp using Instant.

pub fn to_tz<NTZ>(self, tz: NTZ) -> Result<DateTime<NTZ>, CalendarError>
where NTZ: TimeZone,

Returns a new instance with the internal values converted to the provided timezone.

pub fn to_utc(self) -> Result<DateTime<Utc>, CalendarError>

Returns a new instance with the internal values converted to UTC.

pub const fn trunc_to_ms(self) -> Self

Returns a new instance with the number of nanoseconds truncated to milliseconds.

pub const fn trunc_to_sec(self) -> Self

Returns a new instance with the number of nanoseconds totally erased.

pub const fn trunc_to_us(self) -> Self

Returns a new instance with the number of nanoseconds truncated to microseconds.