Instant

Struct Instant 

pub struct Instant { /* private fields */ }
Time provider suitable for operations involving intervals.

Implementations

Source

impl Instant

pub const fn epoch(_secs: u64) -> Result<Self>

Creates an instance that refers the UNIX epoch (1970-01-01).

secs is the amount of seconds passed since the UNIX epoch. This parameter is only relevant for few no_std devices that can’t natively provide time measurements, as such, regular users should simply pass zero.

pub fn now() -> Self

Returns the system time corresponding to “now”. Can have different durations depending on the underlying provider.

pub fn now_date_time(secs: u64) -> Result<DateTime<Utc>>

Returns a new DateTime instance with the current date and time in UTC based on the UNIX epoch.

secs is the amount of seconds passed since the UNIX epoch. This parameter is only relevant for few no_std devices that can’t natively provide time measurements, as such, regular users should simply pass zero.

pub fn now_timestamp(secs: u64) -> Result<Duration>

Constructor that returns the number of non-leap seconds since the UNIX epoch.

secs is the amount of seconds passed since the UNIX epoch. This parameter is only relevant for few no_std devices that can’t natively provide time measurements, as such, regular users should simply pass zero.

pub fn add(&self, _duration: Duration) -> Result<Self>

Returns the addition if the resulting value is within bounds.

pub fn sub(&self, _duration: Duration) -> Result<Self>

Returns the difference if the resulting value is within bounds.

pub fn duration_since(&self, _earlier: Self) -> Result<Duration>

Returns the amount of time elapsed from another instant to this one, or an error if that instant is later than this one.

pub fn elapsed(&self) -> Result<Duration>

Returns the amount of time elapsed since this instant was created.

pub fn timestamp(&self, secs: u64) -> Result<Duration>

Non-constructor method that returns the number of non-leap seconds since the UNIX epoch based on the current instance.

secs is the amount of seconds passed since the UNIX epoch. This parameter is only relevant for few no_std devices that can’t natively provide time measurements, as such, regular users should simply pass zero.