pub enum VectorError {
CapacityOverflow,
ExtendFromSliceOverflow,
ExtendFromSlicesOverflow,
OutOfBoundsInsertIdx,
PushOverflow,
ReserveOverflow,
VecOverflow,
}Expand description
Errors of Vector.
Variants
CapacityOverflow
It was not possible to reserve more memory
ExtendFromSliceOverflow
There is no capacity left to insert a set of new elements.
ExtendFromSlicesOverflow
There is no capacity left to insert a set of new elements.
OutOfBoundsInsertIdx
The index provided in the insert method is out of bounds.
PushOverflow
There is no capacity left to insert a new element.
ReserveOverflow
It was not possible to reserve more memory
VecOverflow
A temporary Vec expanded the capacity beyond the current length type