Module postgres

Module postgres 

Available on crate features database and postgres only.
Postgres, is a free and open-source relational database management system (RDBMS) emphasizing extensibility and SQL compliance.

Structs

Batch
Sends multiple statements at once and awaits them when flushed.
Config
Configuration
DbError
A Postgres error or notice.
DecodeWrapper
Struct used for decoding elements in PostgreSQL.
EncodeWrapper
Struct used for encoding elements in PostgreSQL.
ExecutorBuffer
Buffer used for internal operations.
Postgres
Postgres
PostgresExecutor
Executor
PostgresRecord
Record
PostgresRecords
Records
StructDecoder
Decodes a custom PostgreSQL type that represents a table into a Rust struct.
StructEncoder
Encodes a Rust struct into a custom PostgreSQL type that represents a table.

Enums

ErrorPosition
Position of an error in a query.
PostgresError
PostgreSQL error
Severity
The severity of a Postgres error or notice.
SqlState
SQLSTATE error code
Ty
Type