pub enum DatabaseError {
InconsistentStatementBuilder,
MissingFieldDataInDecoding(Box<str>),
MissingSingleRecord,
UnexpectedBufferSize {
expected: u32,
received: u32,
},
UnexpectedRecords,
UnexpectedValueFromBytes {
expected: &'static str,
},
UnknownStatementId,
}Available on crate feature
database only.Expand description
Database Error
Variants
InconsistentStatementBuilder
The method expand of StatementBuilder must be called only once.
MissingFieldDataInDecoding(Box<str>)
A “null” field received from the database was decoded as a non-nullable type or value.
MissingSingleRecord
Expected one record but got none.
UnexpectedBufferSize
Received size differs from expected size.
UnexpectedRecords
Expected no records but got at least one.
UnexpectedValueFromBytes
Bytes don’t represent expected type
UnknownStatementId
Received a statement ID that is not present in the local cache.