pub struct JsonRpcNotificationParams<R> {
pub result: R,
pub subscription: u64,
}Expand description
A Structured value that holds the parameter values to be used during the invocation of the method.
Fields
result: RPayload
subscription: u64Identifier returned by the counterpart