Error

Enum Error 

pub enum Error {
Show 92 variants AeadError(Error), Argon2(Error), CryptoCommonInvalidLength(InvalidLength), DecodeError(Box<DecodeError>), DecodeSliceError(Box<DecodeSliceError>), EmbassyNet(Error), EncodeSliceError(EncodeSliceError), Flate2CompressError(Box<CompressError>), Flate2DecompressError(Box<DecompressError>), GetRandomError(Error), HttpParse(Error), MatchitError(MatchError), MatchitInsertError(Box<InsertError>), MacError(MacError), QuickProtobuf(Box<Error>), RsaError(Box<Error>), RustlsError(Box<Error>), SerdeDeValue(Box<Error>), SerdeJson(Error), SerdeJsonDeserialize(Box<String>), SpkiError(Box<Error>), TokioJoinError(Box<JoinError>), TryInitError(Box<TryInitError>), TryLockError(TryLockError<()>), UuidError(Box<Error>), AddrParseError(AddrParseError), Fmt(Error), IoError(Error), ParseIntError(ParseIntError), RecvError(RecvError), SendError(SendError<()>), TryFromIntError(TryFromIntError), TryFromSliceError(TryFromSliceError), VarError(VarError), Utf8Error(Box<Utf8Error>), AllocError(Box<Layout>), ClosedConnection, ClosedHttpConnection, ClosedWebSocketConnection, ExpiredFuture, FuturePolledAfterFinalization, Generic(Box<String>), InsufficientOptionCapacity, InvalidAes256GcmData, InvalidPartitionedBufferBounds, InvalidUTF8, InvalidUTF8Bound, InvalidUri, MissingCaProviders, MissingVar(Box<&'static str>), MissingVarQuote(Box<String>), MlockError, MunlockError, NoAvailableVars(Box<String>), NoInnerValue(Box<&'static str>), OutOfBoundsArithmetic, ProgrammingError, UnboundedNumber { expected: RangeInclusive<i32>, received: i32, }, UnexpectedBufferState, UnexpectedBytes { length: u16, ty: ArrayStringU8<9>, }, UnexpectedStreamReadEOF, UnexpectedStreamWriteEOF, UnexpectedString { length: usize, }, UnexpectedUint { received: u64, }, UnsupportedMlockPlatform, UnsupportedOperation, UriCanNotBeOverwritten, UsizeConversionOverflow, VectoredWriteOverflow, ArrayStringError(ArrayStringError), ArrayVectorError(ArrayVectorError), BlocksQueueError(BlocksDequeError), CalendarError(CalendarError), ClientApiFrameworkError(ClientApiFrameworkError), Cookie(CookieError), DatabaseError(Box<DatabaseError>), DecError(DecError), FromRadix10Error(FromRadix10Error), HexError(HexError), HttpError(HttpError), Http2ErrorGoAway(Http2ErrorCode, Http2Error), Http2FlowControlError(Http2Error, u32), MysqlDbError(Box<DbError>), MysqlError(MysqlError), PostgresDbError(Box<DbError>), PostgresError(PostgresError), QueueError(DequeueError), SchemaManagerError(SchemaManagerError), ServerFrameworkError(ServerFrameworkError), SessionError(SessionError), VectorError(VectorError), WebSocketError(WebSocketError),
}
Grouped individual errors

Variants



AeadError(Error)

Available on crate feature aes-gcm only.

See the documentation of the associated element.



Argon2(Error)

Available on crate feature argon2 only.

See the documentation of the associated element.



CryptoCommonInvalidLength(InvalidLength)

Available on crate feature crypto-common only.

See the documentation of the associated element.



DecodeError(Box<DecodeError>)

Available on crate feature base64 only.

See the documentation of the associated element.



DecodeSliceError(Box<DecodeSliceError>)

Available on crate feature base64 only.

See the documentation of the associated element.



EmbassyNet(Error)

Available on crate feature embassy-net only.

See the documentation of the associated element.



EncodeSliceError(EncodeSliceError)

Available on crate feature base64 only.

See the documentation of the associated element.



Flate2CompressError(Box<CompressError>)

Available on crate feature flate2 only.

See the documentation of the associated element.



Flate2DecompressError(Box<DecompressError>)

Available on crate feature flate2 only.

See the documentation of the associated element.



GetRandomError(Error)

Available on crate feature getrandom only.

See the documentation of the associated element.



HttpParse(Error)

Available on crate feature httparse only.

See the documentation of the associated element.



MatchitError(MatchError)

Available on crate feature matchit only.

See the documentation of the associated element.



MatchitInsertError(Box<InsertError>)

Available on crate feature matchit only.

See the documentation of the associated element.



MacError(MacError)

Available on crate feature digest only.

See the documentation of the associated element.



QuickProtobuf(Box<Error>)

Available on crate feature quick-protobuf only.

See the documentation of the associated element.



RsaError(Box<Error>)

Available on crate feature rsa only.

See the documentation of the associated element.



RustlsError(Box<Error>)

Available on crate feature rustls only.

See the documentation of the associated element.



SerdeDeValue(Box<Error>)

Available on crate feature serde only.

See the documentation of the associated element.



SerdeJson(Error)

Available on crate feature serde_json only.

See the documentation of the associated element.



SerdeJsonDeserialize(Box<String>)

Available on crate feature serde_json only.

See the documentation of the associated element.



SpkiError(Box<Error>)

Available on crate feature spki only.

See the documentation of the associated element.



TokioJoinError(Box<JoinError>)

Available on crate feature tokio only.

See the documentation of the associated element.



TryInitError(Box<TryInitError>)

Available on crate feature tracing-subscriber only.

See the documentation of the associated element.



TryLockError(TryLockError<()>)

Available on crate feature std only.

See the documentation of the associated element.



UuidError(Box<Error>)

Available on crate feature uuid only.

See the documentation of the associated element.



AddrParseError(AddrParseError)

See the documentation of the associated element.



Fmt(Error)

See the documentation of the associated element.



IoError(Error)

Available on crate feature std only.

See the documentation of the associated element.



ParseIntError(ParseIntError)

See the documentation of the associated element.



RecvError(RecvError)

See the documentation of the associated element.



SendError(SendError<()>)

See the documentation of the associated element.



TryFromIntError(TryFromIntError)

See the documentation of the associated element.



TryFromSliceError(TryFromSliceError)

See the documentation of the associated element.



VarError(VarError)

Available on crate feature std only.

See the documentation of the associated element.



Utf8Error(Box<Utf8Error>)

See the documentation of the associated element.



AllocError(Box<Layout>)

Allocation error



ClosedConnection

A connection was unexpectedly closed by an external actor or because of a local error.



ClosedHttpConnection

A HTTP connection was unexpectedly closed by an external actor or because of a local error.



ClosedWebSocketConnection

A WebSocket connection was unexpectedly closed by an external actor or because of a local error.



ExpiredFuture

Future should complete before a certain duration but didn’t



FuturePolledAfterFinalization

Future must not be polled again after finalization



Generic(Box<String>)

Generic error



InsufficientOptionCapacity

It is not possible to add an element into an Option because it is already occupied.



InvalidAes256GcmData

Data must have a nonce and a tag.



InvalidPartitionedBufferBounds

Indices are out-of-bounds or the number of bytes are too small.



InvalidUTF8

Invalid UTF-8.



InvalidUTF8Bound

An index that cuts an UTF-8 string makes the sequence invalid.



InvalidUri

Invalid URI



MissingCaProviders

There is no CA provider.



MissingVar(Box<&'static str>)

A instance could not be constructed because of a missing required variable.



MissingVarQuote(Box<String>)

A variable does not have an ending quote



MlockError

Something prevented a mlock operation



MunlockError

Something prevented a munlock operation



NoAvailableVars(Box<String>)

A variable does not have an ending quote



NoInnerValue(Box<&'static str>)

Usually used to transform Options into Results



OutOfBoundsArithmetic

A set of arithmetic operations resulted in an overflow, underflow or division by zero



ProgrammingError

An error that shouldn’t exist. If this variant is raised, then it is very likely that the involved code was not built the way it should be.



UnboundedNumber

Unexpected Unsigned integer

Fields

expected: RangeInclusive<i32>

Expected bounds

received: i32

Received number



UnexpectedBufferState

A buffer was partially read or write but should in fact be fully processed.



UnexpectedBytes

Unexpected bytes

Fields

length: u16

Length of the unexpected bytes

ty: ArrayStringU8<9>

Name of the associated entity



UnexpectedStreamReadEOF

Unexpected end of file when reading from a stream.



UnexpectedStreamWriteEOF

Unexpected end of file when writing to a stream.



UnexpectedString

Unexpected string

Fields

length: usize

Length of the unexpected string



UnexpectedUint

Unexpected Unsigned integer

Fields

received: u64

Number value



UnsupportedMlockPlatform

The operation mlock is not supported in your platform



UnsupportedOperation

Unsupported operation



UriCanNotBeOverwritten

Only appending is possible but overwritten is still viable through resetting.



UsizeConversionOverflow

In the current platform a number is larger than usize.



VectoredWriteOverflow

It is not possible to write more than 8 slices at once.



ArrayStringError(ArrayStringError)

See the documentation of the associated element.



ArrayVectorError(ArrayVectorError)

See the documentation of the associated element.



BlocksQueueError(BlocksDequeError)

See the documentation of the associated element.



CalendarError(CalendarError)

See the documentation of the associated element.



ClientApiFrameworkError(ClientApiFrameworkError)

Available on crate feature client-api-framework only.

See the documentation of the associated element.



Cookie(CookieError)

Available on crate feature http-cookie only.

See the documentation of the associated element.



DatabaseError(Box<DatabaseError>)

Available on crate feature database only.

See the documentation of the associated element.



DecError(DecError)

See the documentation of the associated element.



FromRadix10Error(FromRadix10Error)

See the documentation of the associated element.



HexError(HexError)

See the documentation of the associated element.



HttpError(HttpError)

Available on crate feature http only.

See the documentation of the associated element.



Http2ErrorGoAway(Http2ErrorCode, Http2Error)

Available on crate feature http2 only.

See the documentation of the associated element.



Http2FlowControlError(Http2Error, u32)

Available on crate feature http2 only.

See the documentation of the associated element.



MysqlDbError(Box<DbError>)

Available on crate feature mysql only.

See the documentation of the associated element.



MysqlError(MysqlError)

Available on crate feature mysql only.

See the documentation of the associated element.



PostgresDbError(Box<DbError>)

Available on crate feature postgres only.

See the documentation of the associated element.



PostgresError(PostgresError)

Available on crate feature postgres only.

See the documentation of the associated element.



QueueError(DequeueError)

See the documentation of the associated element.



SchemaManagerError(SchemaManagerError)

Available on crate feature schema-manager only.

See the documentation of the associated element.



ServerFrameworkError(ServerFrameworkError)

Available on crate feature http-server-framework only.

See the documentation of the associated element.



SessionError(SessionError)

Available on crate feature http-session only.

See the documentation of the associated element.



VectorError(VectorError)

See the documentation of the associated element.



WebSocketError(WebSocketError)

Available on crate feature web-socket only.

See the documentation of the associated element.