pub enum SendError<T> {
Full(T),
Disconnected(T),
}Expand description
An error returned by the sending part of a channel
Variants
Full(T)
The message could not be sent because the channel is full.
Disconnected(T)
The message could not be sent because the channel is disconnected.
Implementations