Module http

Module http 

Available on crate feature http only.
Generic HTTP elements

Modules

client_poolhttp-client-pool
Structures used to construct a pool of HTTP connections
server_frameworkhttp-server-framework
Tools and libraries that make it easier to write, maintain, and scale web applications.
web_authn
Structures of https://www.w3.org/TR/webauthn-3

Structs

AutoStream
HTTP stream that is automatically managed by the system. In other words, all frames are gathered until an end-of-stream flag is received and only then a response is sent.
Header
A field of an HTTP request or response.
HeaderName
HTTP header name
Headers
List of pairs sent and received on every request/response.
HttpRecvParams
Indicates to a remote peer the receiving parameters of a connection as well as its streams.
ManualStream
HTTP stream that is manually managed by the user. For example, WebSockets over streams.
Matcher
Decomposes a series of prefixed routes into common nodes to allow fast comparisons with other dynamic routes.
MatcherBuilder
Constructs routes
MatcherPath
Path constructed from a root route
MatcherPathParam
Route match parameter
MsgBuffer
An HTTP message buffer can refer a request or a response.
MsgBuilder
Request/Response Builder
MsgBuilderInput
A tailored Either.
OptionedServeroptioned-server
Optioned abstractions of low-level servers.
ReqBuilder
Request builder
Request
An HTTP request received by a server or to be sent by a client.
ResBuilder
Response builder
Response
Represents the response from an HTTP request.
SessionManagerhttp-session
Manages sessions
SessionManagerBuilderhttp-session
Default and optional parameters for the construction of a SessionManager.
SessionManagerInnerhttp-session
Allows the management of state across requests within a connection.
SessionMiddlewarehttp-server-framework and http-session
Decodes cookies received from requests and manages them.
SessionStatehttp-session
Data that is saved in the corresponding store.

Enums

CookieErrorhttp-cookie
Cookie error
HttpError
Http error
KnownHeaderName
A statically known set of header names
MatcherError
Matcher Error
Method
HTTP method
Mime
Used to specify the data type that is going to be sent to a counterpart.
OperationMode
Tells how an HTTP stream should be handled.
Protocol
Specifies a tunneling protocol
SameSitehttp-cookie
Controls whether or not a cookie is sent with cross-site requests
SessionErrorhttp-session
Session error
StatusCode
HTTP status codes.
Trailers
Tells how trailers are placed in the headers
Version
HTTP version

Constants

MAX_HEADER_NAME_LEN
Maximum number of bytes for the name of a header.
MAX_HEADER_VALUE_LEN
Maximum number of bytes for the value of a header.
WTX_USER_AGENT
Current user agent of this project

Traits

GenericHeader
HTTP header.
GenericRequest
HTTP request.
GenericResponse
HTTP response
HttpClient
Generic HTTP client
MsgData
An HTTP message data can refer a request or a response.
MsgDataMut
Mutable version of MsgData.
OperationModeStream
Operation Mode Stream
SessionStorehttp-session
Abstraction for different session storages.

Functions

is_web_socket_handshake
Verifies if the initial received HTTP/2 headers represent a WebSocket connection.
session_state_rslthttp-session
Convert an optional SessionState a Result.

Type Aliases

ManualServerStreamhttp2
Manual server stream backed by tokio structures.
MsgBufferStr
A request or a response where the URI is an immutable string slice.
MsgBufferString
A request or a response where the URI is a dynamic string buffer.