ServerFrameworkBuilder

Struct ServerFrameworkBuilder 

pub struct ServerFrameworkBuilder<CA, CBP, E, EN, M, S, SA> { /* private fields */ }
Available on crate features http and http-server-framework only.
Server

Implementations

Source

impl<CA, CBP, E, EN, M, S, SA> ServerFrameworkBuilder<CA, CBP, E, EN, M, S, SA>
where CA: ConnAux, SA: StreamAux,

pub fn new(cbp: CBP, router: Router<CA, E, EN, M, S, SA>) -> Self

New instance with default connection values.

pub const fn enable_connect_protocol(self, elem: bool) -> Self

Maximum number of active concurrent streams

pub fn with_aux<CACB, SACB>( self, ca_cb: CACB, sa_cb: SACB, ) -> ServerFramework<CA, CACB, CBP, E, EN, M, S, SA, SACB>
where CACB: Fn(CBP) -> Result<CA::Init, E>, SACB: Fn(&mut CA) -> Result<SA::Init, E>,

Sets the initialization structures for both CA and SA.

pub fn with_dflt_aux( self, ) -> ServerFramework<CA, fn(CBP) -> CA::Init, CBP, E, EN, M, S, SA, fn(&mut CA) -> SA::Init>
where CA::Init: Default, SA::Init: Default,

Fills the initialization structures for all auxiliaries with default values.

pub const fn initial_window_len(self, elem: u32) -> Self

The initial amount of “credit” a counterpart can have for sending data.

pub const fn max_body_len(self, elem: u32) -> Self

The maximum number of data bytes or the sum of all frames that composed the body data.

pub const fn max_concurrent_streams_num(self, elem: u32) -> Self

Maximum number of active concurrent streams

pub const fn max_frame_len(self, elem: u32) -> Self

Maximum frame payload length

pub const fn max_hpack_len(self, elem: (u32, u32)) -> Self

Maximum HPACK length

Indicates the maximum length of the HPACK structure that holds cached decoded headers received from a counterpart.

  • The first parameter indicates the local HPACK decoder length that is externally advertised and can become the remote HPACK encoder length.
  • The second parameter indicates the maximum local HPACK encoder length. In other words, it doesn’t allow external actors to dictate very large lengths.
pub const fn max_headers_len(self, elem: u32) -> Self

The maximum number of bytes of the entire set of headers in a request/response.

pub const fn max_recv_streams_num(self, elem: u32) -> Self

Maximum number of receiving streams

Servers only. Prevents clients from opening more than the specified number of streams.

Source

impl<CBP, E, EN, M, S> ServerFrameworkBuilder<(), CBP, E, EN, M, S, ()>

pub fn without_aux( self, ) -> ServerFramework<(), fn(CBP) -> Result<(), E>, CBP, E, EN, M, S, (), fn(&mut ()) -> Result<(), E>>

Build without state

Source

impl<CA, CBP, E, EN, M, S> ServerFrameworkBuilder<CA, CBP, E, EN, M, S, ()>
where CA: ConnAux,

pub fn with_conn_aux<CACB>( self, ca_cb: CACB, ) -> ServerFramework<CA, CACB, CBP, E, EN, M, S, (), fn(&mut CA) -> Result<(), E>>
where CACB: Fn(CBP) -> Result<CA::Init, E>,

Sets the initializing strut for CA and sets the request auxiliary to ().

Source

impl<CBP, E, EN, M, S, SA> ServerFrameworkBuilder<(), CBP, E, EN, M, S, SA>
where SA: StreamAux,

pub fn with_stream_aux<SACB>( self, ra_cb: SACB, ) -> ServerFramework<(), fn(CBP) -> Result<(), E>, CBP, E, EN, M, S, SA, SACB>
where SACB: Fn(&mut ()) -> Result<SA::Init, E>,

Sets the initializing strut for SA and sets the connection auxiliary to ().