StreamAux

Trait StreamAux 

pub trait StreamAux: Sized {
    type Init;

    // Required method
    fn stream_aux(init: Self::Init) -> Result<Self>;
}
Available on crate features http and http-server-framework only.
Auxiliary structures for streams or requests.

Required Associated Types

type Init

Initialization

Required Methods

fn stream_aux(init: Self::Init) -> Result<Self>

Creates a new instance with StreamAux::Init as well as with a request.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementations on Foreign Types

Source

impl StreamAux for ()

Source

type Init = ()

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A> StreamAux for (A,)
where A: StreamAux,

Source

type Init = (<A as StreamAux>::Init,)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B> StreamAux for (A, B)
where A: StreamAux, B: StreamAux,

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C> StreamAux for (A, B, C)
where A: StreamAux, B: StreamAux, C: StreamAux,

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D> StreamAux for (A, B, C, D)
where A: StreamAux, B: StreamAux, C: StreamAux, D: StreamAux,

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E> StreamAux for (A, B, C, D, E)
where A: StreamAux, B: StreamAux, C: StreamAux, D: StreamAux, E: StreamAux,

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F> StreamAux for (A, B, C, D, E, F)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G> StreamAux for (A, B, C, D, E, F, G)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H> StreamAux for (A, B, C, D, E, F, G, H)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I> StreamAux for (A, B, C, D, E, F, G, H, I)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J> StreamAux for (A, B, C, D, E, F, G, H, I, J)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K> StreamAux for (A, B, C, D, E, F, G, H, I, J, K)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P)

Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init, <AA as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init, <AA as StreamAux>::Init, <AB as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init, <AA as StreamAux>::Init, <AB as StreamAux>::Init, <AC as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC, AD> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC, AD)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init, <AA as StreamAux>::Init, <AB as StreamAux>::Init, <AC as StreamAux>::Init, <AD as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC, AD, AE> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC, AD, AE)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init, <AA as StreamAux>::Init, <AB as StreamAux>::Init, <AC as StreamAux>::Init, <AD as StreamAux>::Init, <AE as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.
Source

impl<A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC, AD, AE, AF> StreamAux for (A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, AA, AB, AC, AD, AE, AF)

Available on crate feature 32-tuple-impls only.
Source

type Init = (<A as StreamAux>::Init, <B as StreamAux>::Init, <C as StreamAux>::Init, <D as StreamAux>::Init, <E as StreamAux>::Init, <F as StreamAux>::Init, <G as StreamAux>::Init, <H as StreamAux>::Init, <I as StreamAux>::Init, <J as StreamAux>::Init, <K as StreamAux>::Init, <L as StreamAux>::Init, <M as StreamAux>::Init, <N as StreamAux>::Init, <O as StreamAux>::Init, <P as StreamAux>::Init, <Q as StreamAux>::Init, <R as StreamAux>::Init, <S as StreamAux>::Init, <T as StreamAux>::Init, <U as StreamAux>::Init, <V as StreamAux>::Init, <W as StreamAux>::Init, <X as StreamAux>::Init, <Y as StreamAux>::Init, <Z as StreamAux>::Init, <AA as StreamAux>::Init, <AB as StreamAux>::Init, <AC as StreamAux>::Init, <AD as StreamAux>::Init, <AE as StreamAux>::Init, <AF as StreamAux>::Init)

Available on crate feature http only.
Source

fn stream_aux(_init: Self::Init) -> Result<Self>

Available on crate feature http only.

Implementors

Source

impl<DRSR> StreamAux for GrpcManager<DRSR>
where DRSR: Default,

Available on crate features grpc and grpc-server only.
Source

type Init = DRSR

Source

impl<RM> StreamAux for SimplePool<RM>
where RM: ResourceManager,

Available on crate feature std only.