AutoStream

Struct AutoStream 

pub struct AutoStream<CA, SA> {
    pub conn_aux: CA,
    pub peer: IpAddr,
    pub protocol: Option<Protocol>,
    pub req: Request<ReqResBuffer>,
    pub stream_aux: SA,
}
Available on crate feature http only.
HTTP stream that is automatically managed by the system. In other words, all frames are gathered until an end-of-stream flag is received and only then a response is sent.

Fields

conn_aux: CA

Connection auxiliary

peer: IpAddr

Remote peer address

protocol: Option<Protocol>

See Protocol.

req: Request<ReqResBuffer>

Request

stream_aux: SA

Stream auxiliary