#[db]Available on crate feature
macros only.Expand description
Allows the execution of asynchronous database tests using the runtime provided by WTX.
This macro automatically creates an isolated environment with migrations and seeds