Available on crate features
database and postgres only.Expand description
Postgres, is a free and open-source relational database management system (RDBMS) emphasizing extensibility and SQL compliance.
Structs
- Batch
- Sends multiple statements at once and awaits them when flushed.
- Config
- Configuration
- DbError
- A Postgres error or notice.
- Decode
Wrapper - Struct used for decoding elements in PostgreSQL.
- Encode
Wrapper - Struct used for encoding elements in PostgreSQL.
- Executor
Buffer - Buffer used for internal operations.
- Postgres
- Postgres
- Postgres
Executor - Executor
- Postgres
Record - Record
- Postgres
Records - Records
- Struct
Decoder - Decodes a custom PostgreSQL type that represents a table into a Rust struct.
- Struct
Encoder - Encodes a Rust struct into a custom PostgreSQL type that represents a table.
Enums
- Error
Position - Position of an error in a query.
- Postgres
Error - PostgreSQL error
- Severity
- The severity of a Postgres error or notice.
- SqlState
- SQLSTATE error code
- Ty
- Type