pub enum PostgresError {
Show 18 variants
DecimalCanNotBeConvertedFromNaN,
DecodingError,
InsufficientDbErrorBytes,
InvalidIpFormat,
InvalidJsonFormat,
InvalidPostgresUint,
InvalidPostgresRecord,
InvalidRecordValuesIterator,
MissingChannel,
RequiredChannel,
ServerDoesNotSupportEncryption,
TimeStructureOverflow,
TimeStructureWithGreaterPrecision,
UnexpectedDatabaseMessage {
received: u8,
},
UnexpectedDatabaseMessageBytes,
UnknownAuthenticationMethod,
UnknownConfigurationParameter,
VeryLargeDecimal,
}database and postgres only.Expand description
PostgreSQL error
Variants
DecimalCanNotBeConvertedFromNaN
Not-A-Number is not supported
DecodingError
There are no sufficient bytes to decoding an element
InsufficientDbErrorBytes
There are no bytes left to build a DbError
InvalidIpFormat
Invalid IP format
InvalidJsonFormat
JSONB is the only supported JSON format
InvalidPostgresUint
Postgres does not support large unsigned integers. For example, u8 can only be stored
and read with numbers up to 127.
InvalidPostgresRecord
Received bytes don’t compose a valid record.
InvalidRecordValuesIterator
The iterator that composed a RecordValues does not contain a corresponding length.
MissingChannel
It is required to connect using a TLS channel but the server didn’t provide any. Probably because the connection is unencrypted.
RequiredChannel
It is required to connect without using a TLS channel but the server only provided a way to connect using channels. Probably because the connection is encrypted.
ServerDoesNotSupportEncryption
Server does not support encryption
TimeStructureOverflow
The passed time structure contains a duration that is out of bounds
TimeStructureWithGreaterPrecision
The passed time structure can not have a precision greater than microseconds
UnexpectedDatabaseMessage
Received an unexpected message type.
UnexpectedDatabaseMessageBytes
Received an expected message type but the related bytes are in an unexpected state.
UnknownAuthenticationMethod
The system does not support a requested authentication method.
UnknownConfigurationParameter
The system does not support a provided parameter.
VeryLargeDecimal
The system only supports decimals with 64 digits.