Available on crate feature
http only.Expand description
Generic HTTP elements
Modules
- client_
pool http-client-pool - Structures used to construct a pool of HTTP connections
- server_
framework http-server-framework - Tools and libraries that make it easier to write, maintain, and scale web applications.
- web_
authn - Structures of https://www.w3.org/TR/webauthn-3
Structs
- Auto
Stream - HTTP stream that is automatically managed by the system. In other words, all frames are gathered until an end-of-stream flag is received and only then a response is sent.
- Header
- A field of an HTTP request or response.
- Header
Name - HTTP header name
- Headers
- List of pairs sent and received on every request/response.
- Http
Recv Params - Indicates to a remote peer the receiving parameters of a connection as well as its streams.
- Manual
Stream - HTTP stream that is manually managed by the user. For example, WebSockets over streams.
- Matcher
- Decomposes a series of prefixed routes into common nodes to allow fast comparisons with other dynamic routes.
- Matcher
Builder - Constructs routes
- Matcher
Path - Path constructed from a root route
- Matcher
Path Param - Route match parameter
- MsgBuffer
- An HTTP message buffer can refer a request or a response.
- MsgBuilder
- Request/Response Builder
- MsgBuilder
Input - A tailored
Either. - Optioned
Server optioned-server - Optioned abstractions of low-level servers.
- ReqBuilder
- Request builder
- Request
- An HTTP request received by a server or to be sent by a client.
- ResBuilder
- Response builder
- Response
- Represents the response from an HTTP request.
- Session
Manager http-session - Manages sessions
- Session
Manager Builder http-session - Default and optional parameters for the construction of a
SessionManager. - Session
Manager Inner http-session - Allows the management of state across requests within a connection.
- Session
Middleware http-server-frameworkandhttp-session - Decodes cookies received from requests and manages them.
- Session
State http-session - Data that is saved in the corresponding store.
Enums
- Cookie
Error http-cookie - Cookie error
- Http
Error - Http error
- Known
Header Name - A statically known set of header names
- Matcher
Error - Matcher Error
- Method
- HTTP method
- Mime
- Used to specify the data type that is going to be sent to a counterpart.
- Operation
Mode - Tells how an HTTP stream should be handled.
- Protocol
- Specifies a tunneling protocol
- Same
Site http-cookie - Controls whether or not a cookie is sent with cross-site requests
- Session
Error http-session - Session error
- Status
Code - HTTP status codes.
- Trailers
- Tells how trailers are placed in the headers
- Version
- HTTP version
Constants
- MAX_
HEADER_ NAME_ LEN - Maximum number of bytes for the name of a header.
- MAX_
HEADER_ VALUE_ LEN - Maximum number of bytes for the value of a header.
- WTX_
USER_ AGENT - Current user agent of this project
Traits
- Generic
Header - HTTP header.
- Generic
Request - HTTP request.
- Generic
Response - HTTP response
- Http
Client - Generic HTTP client
- MsgData
- An HTTP message data can refer a request or a response.
- MsgData
Mut - Mutable version of
MsgData. - Operation
Mode Stream - Operation Mode Stream
- Session
Store http-session - Abstraction for different session storages.
Functions
- is_
web_ socket_ handshake - Verifies if the initial received HTTP/2 headers represent a WebSocket connection.
- session_
state_ rslt http-session - Convert an optional
SessionStateaResult.
Type Aliases
- Manual
Server Stream http2 - Manual server stream backed by tokio structures.
- MsgBuffer
Str - A request or a response where the URI is an immutable string slice.
- MsgBuffer
String - A request or a response where the URI is a dynamic string buffer.