pub struct ServerFrameworkBuilder<CA, CBP, E, EN, M, S, SA> { /* private fields */ }http and http-server-framework only.Expand description
Server
Implementations
Sourceimpl<CA, CBP, E, EN, M, S, SA> ServerFrameworkBuilder<CA, CBP, E, EN, M, S, SA>
impl<CA, CBP, E, EN, M, S, SA> ServerFrameworkBuilder<CA, CBP, E, EN, M, S, SA>
Sourcepub fn new(cbp: CBP, router: Router<CA, E, EN, M, S, SA>) -> Self
pub fn new(cbp: CBP, router: Router<CA, E, EN, M, S, SA>) -> Self
New instance with default connection values.
Sourcepub const fn enable_connect_protocol(self, elem: bool) -> Self
pub const fn enable_connect_protocol(self, elem: bool) -> Self
Maximum number of active concurrent streams
Sourcepub fn with_aux<CACB, SACB>(
self,
ca_cb: CACB,
sa_cb: SACB,
) -> ServerFramework<CA, CACB, CBP, E, EN, M, S, SA, SACB>
pub fn with_aux<CACB, SACB>( self, ca_cb: CACB, sa_cb: SACB, ) -> ServerFramework<CA, CACB, CBP, E, EN, M, S, SA, SACB>
Sets the initialization structures for both CA and SA.
Sourcepub fn with_dflt_aux(
self,
) -> ServerFramework<CA, fn(CBP) -> CA::Init, CBP, E, EN, M, S, SA, fn(&mut CA) -> SA::Init>
pub fn with_dflt_aux( self, ) -> ServerFramework<CA, fn(CBP) -> CA::Init, CBP, E, EN, M, S, SA, fn(&mut CA) -> SA::Init>
Fills the initialization structures for all auxiliaries with default values.
Sourcepub const fn initial_window_len(self, elem: u32) -> Self
pub const fn initial_window_len(self, elem: u32) -> Self
The initial amount of “credit” a counterpart can have for sending data.
Sourcepub const fn max_body_len(self, elem: u32) -> Self
pub const fn max_body_len(self, elem: u32) -> Self
The maximum number of data bytes or the sum of all frames that composed the body data.
Sourcepub const fn max_concurrent_streams_num(self, elem: u32) -> Self
pub const fn max_concurrent_streams_num(self, elem: u32) -> Self
Maximum number of active concurrent streams
Sourcepub const fn max_frame_len(self, elem: u32) -> Self
pub const fn max_frame_len(self, elem: u32) -> Self
Maximum frame payload length
Sourcepub const fn max_hpack_len(self, elem: (u32, u32)) -> Self
pub const fn max_hpack_len(self, elem: (u32, u32)) -> Self
Maximum HPACK length
Indicates the maximum length of the HPACK structure that holds cached decoded headers received from a counterpart.
- The first parameter indicates the local HPACK decoder length that is externally advertised and can become the remote HPACK encoder length.
- The second parameter indicates the maximum local HPACK encoder length. In other words, it doesn’t allow external actors to dictate very large lengths.
Sourcepub const fn max_headers_len(self, elem: u32) -> Self
pub const fn max_headers_len(self, elem: u32) -> Self
The maximum number of bytes of the entire set of headers in a request/response.
Sourcepub const fn max_recv_streams_num(self, elem: u32) -> Self
pub const fn max_recv_streams_num(self, elem: u32) -> Self
Maximum number of receiving streams
Servers only. Prevents clients from opening more than the specified number of streams.