Synchronizing primitives
Some of the no_std structures located in this module were copied from the
https://github.com/crossbeam-rs/crossbeam project and modified to fit into wtx. On the
other hand, some structures are just wrappers or facades of third-parties.
Structs
- Arc
- A thread-safe reference-counting pointer. ‘Arc’ stands for ‘Atomically Reference Counted’.
- Async
Mutex - An asynchronous
Mutex-like type. - Async
Mutex Guard - An RAII guard returned by the
lockandtry_lockmethods. When this structure is dropped (falls out of scope), the lock will be unlocked. - Async
Mutex Guard Future - A future which resolves when the target mutex has been successfully acquired.
- Atomic
Bool - An integer type which can be safely shared between threads.
- Atomic
Cell - A type that allows copyable elements to be safely shared between threads.
- Atomic
U32 - An integer type which can be safely shared between threads.
- Atomic
U64 - An integer type which can be safely shared between threads.
- Atomic
Usize - An integer type which can be safely shared between threads.
- Atomic
Waker - Waker that can be shared across tasks.
- Backoff
- Performs exponential backoff in spin loops, which reduces contention that may improve overall performance.
- Cache
Padded - Prevents false sharing by padding and aligning to the length of a cache line.
- Crossbeam
Mpmc crossbeam-channel - Uses the channel provided by the
Crossbeamproject. - StdMpmc
stdandnightly - Uses the channel provided by the standard library.
- Sync
Mutex - A mutual exclusion primitive useful for protecting shared data.
- Sync
Mutex Guard - A RAII implementation of a “scoped lock” of a mutex.
Traits
- Mpmc
- Multi-producer multi-consumer channel.
- Receiver
- The receiving side of a channel.
- RefCounter
- Reference Counter
- Sender
- The sending side of a channel.
Functions
- fence
- An atomic fence.