pub trait RefCounter: Clone + Deref<Target = Self::Item> {
type Item;
// Required method
fn new(elem: Self::Item) -> Self;
}Expand description
Reference Counter
Stores the number of references, pointers, or handles to a resource, such as an object, a block of memory, disk space and others.
Required Associated Types
Required Methods
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.